# Deker Tools

Deker Tools is a utility package for the Deker project. It includes tools for working with data, paths, slices and time.

## Installation
You can install the tools as a part of the Deker project.

## Documentation
link
